/*
# #############################################################################
#  ATTENTION
# #############################################################################
#
#  This software is for guidance only. It is provided "as is".
#  It only aims at providing coding information to the customer in order for
#  them to save time. As a result no warranties, whether express, implied or
#  statutory, including, but not limited to implied warranties of
#  merchantability and fitness for a particular purpose apply to this software.
#  A·P·E Angewandte Physik und Elektronik GmbH shall not be held liable for any
#  direct, indirect or consequential damages with respect to any claims arising
#  from the content of such sourcecode and/or the use made by customers of the
#  coding information contained herein in connection with their products.
#
#  File Version: 1.0
#
#  Changelog:
#    1.0 - Initial Version
#
# #############################################################################
*/
#include "stdafx.h"
#include "ape_device.hpp" //ape_device class

void wait_for_key(); // Programm halts until keypress

using namespace std;


//-----------------------------------------------------------------------------
// MAIN PROGRAM
//-----------------------------------------------------------------------------
int _tmain(int argc, _TCHAR* argv[])
{
	//Create a new APE_Device object 
	//(class constructor will automatically try to connect to the given host/port)
	//
	//Usage:
	//APE_Device device(<hostname or IP address>, <TCP Portnumber>, <Custom device alias>);
	APE_Device device("localhost", 51019, "APEDevice");

	//Request IDN-String
	cout << "Device IDN: " + device.get_idn() << endl;
	
	//Wait until user presses any key
	wait_for_key();

	//Disconnect from remote host, since no more data will be sent or read
	device.disconnect();

	return 0;
}


//-----------------------------------------------------------------------------
// Wait for key function
//
//Parameters:
//	none
//
//Returns:
//	none
//
//Note:
//	Waits until the user presses a key, while the terminal window is frontmost
//	this adapts the unix getc() function, which is not present in windows OS
//-----------------------------------------------------------------------------
void wait_for_key()
{

// every keypress registered, also arrow keys
#if defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__TOS_WIN__)  
	cout << endl << "Press any key to continue..." << endl;

	FlushConsoleInputBuffer(GetStdHandle(STD_INPUT_HANDLE));
	_getch();
#elif defined(unix) || defined(__unix) || defined(__unix__) || defined(__APPLE__)
	cout << endl << "Press ENTER to continue..." << endl;

	std::cin.clear();
	std::cin.ignore(std::cin.rdbuf()->in_avail());
	std::cin.get();
#endif
	return;
}
