/*
# #############################################################################
#  ATTENTION
# #############################################################################
#
#  This software is for guidance only. It is provided "as is".
#  It only aims at providing coding information to the customer in order for
#  them to save time. As a result no warranties, whether express, implied or
#  statutory, including, but not limited to implied warranties of
#  merchantability and fitness for a particular purpose apply to this software.
#  A·P·E Angewandte Physik und Elektronik GmbH shall not be held liable for any
#  direct, indirect or consequential damages with respect to any claims arising
#  from the content of such sourcecode and/or the use made by customers of the
#  coding information contained herein in connection with their products.
#
#  File Version: 1.0
#
#  Changelog:
#    1.0 - Initial Version
#
# #############################################################################
*/

#define WIN32_LEAN_AND_MEAN //enable include of multiple libs inside windows.h

#include "stdafx.h"

#ifndef APEDEVICEHPP
	#include <windows.h>
	#include <winsock2.h>
	#include <ws2tcpip.h>
	#include <stdlib.h>
	#include <stdio.h>
	#include <conio.h>
	#include <iostream>
	#include<string>
	#define APEDEVICEHPP
#endif

// Need to link with Ws2_32.lib, Mswsock.lib, and Advapi32.lib
#pragma comment (lib, "Ws2_32.lib")
#pragma comment (lib, "Mswsock.lib")
#pragma comment (lib, "AdvApi32.lib")

#define BUFFER_LEN 524288 //512KB receive buffer size

//-------------------------------------------------------------------------
// APE_Device Class
//-------------------------------------------------------------------------
class APE_Device
{
//Private Variables and Functions (only accessible from within class functions)
private:
	//Classvariables
	WSADATA wsaData; //Data Socket (Winsock)
	SOCKET ConnectSocket = INVALID_SOCKET; //Socket Object
	struct addrinfo
		*result = NULL,
		*ptr = NULL,
		hints; //TCP Address Structure
	float socket_timeout = 5.0; //Timeout in seconds for socket read/write actions
	char recvbuffer[BUFFER_LEN]; //Receive buffer
	std::string remote_port = "51019"; 	// Remote Port
	std::string remote_host = "localhost"; // Remote Hostname (or IP)
	std::string custom_name = "APEDevice"; // Custom Devicename
	bool is_connected = false;

	//Read SCPI Block function
	std::string recv_scpi();

//Public Functions
public:
	APE_Device(std::string hostname, int port, std::string devicename);
	~APE_Device();
	std::string set_host(std::string hostname);
	unsigned int set_port(unsigned int port);
	float set_timeout(float timeout);
	int open_connection(void);
	bool disconnect(void);
	bool connected(void);
	int send_data(std::string command);
	std::string recv_data(int length, bool recv_scpi_block = false);
	std::string query(std::string command, bool recv_scpi_block = false);
	std::string get_idn(void);
	int get_status(void);
	int get_oper(void);
};